@@ -9,7 +9,8 @@ from dask import dataframe as dd
 def create_dask_df(database=None,
                    table=None,
                    gcs_bucket=None,
-                   date_columns=None):
+                   date_columns=None,
+                   date_parser=None):
 
     curr_date = datetime.now().strftime('%Y-%m-%d')
     filename = f'{table}-extract-{curr_date}.csv'
@@ -24,7 +25,6 @@ def create_dask_df(database=None,
     data_types = json.loads(dt_blob)
 
     if date_columns:
-        def date_parser(x): return pd.to_datetime(x, errors='coerce')
         ddf = dd.read_csv(data_path, delimiter='|', dtype=data_types,
                           parse_dates=date_columns, date_parser=date_parser)
     else:
